/*
 * file ControllableSymbolicLink.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 * 
 * (c) Copyright IBM Corporation 2007, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */
package javax.wvcm;

import javax.wvcm.PropertyNameList.PropertyName;

/**
 * A proxy for a symbolic link resource.
 * The content of a symbolic link is the content of the resource to which its
 * {@link #LINK_TARGET} property refers.
 * The members of a symbolic link are the members of the resource to which its
 * {@link #LINK_TARGET} property refers.
 * 
 * A controllable symbolic link resource is a symbolic link that can be placed under control.
 * When a symbolic link is placed under version control, a version of that symbolic link
 * captures the link-pathname value of that symbolic link.
 * 
 * @since 1.1
 */
public interface ControllableSymbolicLink extends ControllableFolder {
    
    /**
     * A pathname that identifies the resource to which the symbolic link refers.
     * @see #setLinkTarget
     * @see #getLinkTarget
     */
    public static final PropertyName<Location> LINK_TARGET =
        new PropertyName<Location>("link-target"); //$NON-NLS-1$

    /**
     * Get the {@link #LINK_TARGET} property.
     * 
     * @return the {@link #LINK_TARGET} property.
     * @throws WvcmException if this property was not set and
     * this ControllableSymbolicLink was not created with
     * {@link #LINK_TARGET} as a wanted property.
     * @see #setLinkTarget
     */
    public Location getLinkTarget() throws WvcmException;

    /**
     * Set the {@link #LINK_TARGET} property.
     * 
     * @param linkTarget the new pathname
     * value for the {@link #LINK_TARGET} property.
     * @see #getLinkTarget
     */
    public void setLinkTarget(Location linkTarget);

}
